@@ -18,7 +18,7 @@ extern "C" {
 #endif
 
 #ifndef _PATH_MAILDIR
-#define _PATH_MAILDIR "/var/mail"
+#include <paths.h>
 #endif
 
 #define MAILDIR		(_PATH_MAILDIR "/")
